@@ -2,8 +2,14 @@
 the module exists """
 from importlib.util import find_spec, module_from_spec
 
+try:  # for pip >= 10
+    from pip._internal.req import parse_requirements
+except ImportError:  # for pip <= 9.0.3
+    from pip.req import parse_requirements
+
 from apu.exception.module import ModuleNotImportedError
 
+
 class Module:
     """in this class all module containing functions are placed."""
     @staticmethod
@@ -62,3 +68,13 @@ class Module:
             raise ModuleNotFoundError(f"{module_name} not found") from mnf
         except AttributeError as ate:
             raise AttributeError(f"{module_name} attribute not valid") from ate
+
+    # pylint: disable=W0702
+    @staticmethod
+    def load_requirements(fname):
+        """ install missing pip packages """
+        reqs = parse_requirements(fname, session=False)
+        try:
+            return [str(ir.requirement) for ir in reqs]
+        except:
+            return [str(ir.req) for ir in reqs]
